==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QTextOption_Tab_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qtextoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextOption_Tab(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextOption::Tab")
    QTextOption::Tab *_ptr = reinterpret_cast<QTextOption::Tab *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Tab()
void __qt_construct_QTextOption_Tab_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab()")
    Q_UNUSED(__java_arguments)
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new Tab(qreal,QTextOption::TabType,QChar)
void __qt_construct_QTextOption_Tab_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab(qreal,QTextOption::TabType,QChar)")
    jdouble pos0 = __java_arguments[0].d;
    Q_UNUSED(pos0)
    jobject tabType1 = __java_arguments[1].l;
    QTextOption::TabType __qt_tabType1 = qtjambi_cast<QTextOption::TabType>(__jni_env, tabType1);
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab(static_cast<qreal>(pos0), QTextOption::TabType(__qt_tabType1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new Tab(qreal,QTextOption::TabType,QChar)
void __qt_construct_QTextOption_Tab_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab(qreal,QTextOption::TabType,QChar)")
    jdouble pos0 = __java_arguments[0].d;
    Q_UNUSED(pos0)
    jobject tabType1 = __java_arguments[1].l;
    QTextOption::TabType __qt_tabType1 = qtjambi_cast<QTextOption::TabType>(__jni_env, tabType1);
    jchar delim2 = __java_arguments[2].c;
    QChar __qt_delim2 = qtjambi_cast<QChar>(__jni_env, delim2);
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab(static_cast<qreal>(pos0), QTextOption::TabType(__qt_tabType1), __qt_delim2);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QTextOption::Tab
void __qt_destruct_QTextOption_Tab(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextOption::Tab")
    reinterpret_cast<QTextOption::Tab*>(ptr)->~Tab();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextOption::Tab::Tab()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_initialize_1native__Lio_qt_gui_QTextOption_00024Tab_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextOption::Tab::Tab()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextOption_Tab_0, sizeof(QTextOption::Tab), typeid(QTextOption::Tab), false, &deleter_QTextOption_Tab, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextOption::Tab::Tab(qreal,QTextOption::TabType,QChar)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_initialize_1native__Lio_qt_gui_QTextOption_00024Tab_2DLio_qt_gui_QTextOption_00024TabType_2C)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble pos0,
 jobject tabType1,
 jchar delim2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextOption::Tab::Tab(qreal,QTextOption::TabType,QChar)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].d = pos0;
        arguments[1].l = tabType1;
        arguments[2].c = delim2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextOption_Tab_2, sizeof(QTextOption::Tab), typeid(QTextOption::Tab), false, &deleter_QTextOption_Tab, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextOption::Tab::operator==(QTextOption::Tab)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_equals_1native_1cref_1QTextOption_1Tab_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextOption::Tab::operator==(QTextOption::Tab)const", __qt_this)
        const QTextOption::Tab& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QTextOption::Tab>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_setDelimiter_1native_1cref_1QChar__JC)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jchar delimiter0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QChar __qt_delimiter0 = qtjambi_cast<QChar>(__jni_env, delimiter0);
        __qt_this->delimiter = __qt_delimiter0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jchar JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_delimiter_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jchar __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QChar&  __qt_value = __qt_this->delimiter;
        __java_return_value = __qt_value.unicode();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_setPosition_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble position0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->position = static_cast<qreal>(position0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_position_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->position;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_setType_1native_1cref_1QTextOption_1TabType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTextOption::TabType __qt_type0 = qtjambi_cast<QTextOption::TabType>(__jni_env, type0);
        __qt_this->type = QTextOption::TabType(__qt_type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextOption::TabType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextOption_Tab(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextOption::Tab>("QTextOption::Tab", "io/qt/gui/QTextOption$Tab");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextOption_Tab, {
        ConstructorInfo(&__qt_construct_QTextOption_Tab_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextOption_Tab_1, "DLio/qt/gui/QTextOption$TabType;")
       ,ConstructorInfo(&__qt_construct_QTextOption_Tab_2, "DLio/qt/gui/QTextOption$TabType;C")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextOption_Tab);
    registerMetaType<QTextOption::Tab>("QTextOption::Tab");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QTextOption_Tab_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qtextoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiGui/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTextOption_Tab(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextOption::Tab")
    QTextOption::Tab *_ptr = reinterpret_cast<QTextOption::Tab *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Tab()
void __qt_construct_QTextOption_Tab(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab()")
    Q_UNUSED(__java_arguments)
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextOption::Tab::Tab()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_initialize_1native__Lio_qt_gui_QTextOption_00024Tab_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextOption::Tab::Tab()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextOption_Tab, sizeof(QTextOption::Tab), typeid(QTextOption::Tab), false, &deleter_QTextOption_Tab, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Tab(QTextOption::Tab)
void __qt_construct_QTextOption_Tab_cref_QTextOption_Tab(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab(QTextOption::Tab)")
    jobject other0 = __java_arguments[0].l;
    const QTextOption::Tab& __qt_other0 = qtjambi_cast<const QTextOption::Tab& >(__jni_env, other0);
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextOption::Tab::Tab(QTextOption::Tab)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_initialize_1native__Lio_qt_gui_QTextOption_00024Tab_2Lio_qt_gui_QTextOption_00024Tab_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextOption::Tab::Tab(QTextOption::Tab)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextOption_Tab_cref_QTextOption_Tab, sizeof(QTextOption::Tab), typeid(QTextOption::Tab), false, &deleter_QTextOption_Tab, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Tab(qreal,QTextOption::TabType,QChar)
void __qt_construct_QTextOption_Tab_qreal_QTextOption_TabType(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab(qreal,QTextOption::TabType,QChar)")
    jdouble pos0 = __java_arguments[0].d;
    Q_UNUSED(pos0)
    jobject tabType1 = __java_arguments[1].l;
    QTextOption::TabType __qt_tabType1 = qtjambi_cast<QTextOption::TabType>(__jni_env, tabType1);
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab(static_cast<qreal>(pos0), QTextOption::TabType(__qt_tabType1));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new Tab(qreal,QTextOption::TabType,QChar)
void __qt_construct_QTextOption_Tab_qreal_QTextOption_TabType_QChar(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Tab(qreal,QTextOption::TabType,QChar)")
    jdouble pos0 = __java_arguments[0].d;
    Q_UNUSED(pos0)
    jobject tabType1 = __java_arguments[1].l;
    QTextOption::TabType __qt_tabType1 = qtjambi_cast<QTextOption::TabType>(__jni_env, tabType1);
    jchar delim2 = __java_arguments[2].c;
    QChar __qt_delim2 = qtjambi_cast<QChar>(__jni_env, delim2);
    QTextOption::Tab *__qt_this = new(__qtjambi_ptr) QTextOption::Tab(static_cast<qreal>(pos0), QTextOption::TabType(__qt_tabType1), __qt_delim2);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTextOption::Tab::Tab(qreal,QTextOption::TabType,QChar)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_initialize_1native__Lio_qt_gui_QTextOption_00024Tab_2DLio_qt_gui_QTextOption_00024TabType_2C)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble pos0,
 jobject tabType1,
 jchar delim2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextOption::Tab::Tab(qreal,QTextOption::TabType,QChar)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].d = pos0;
        arguments[1].l = tabType1;
        arguments[2].c = delim2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextOption_Tab_qreal_QTextOption_TabType_QChar, sizeof(QTextOption::Tab), typeid(QTextOption::Tab), false, &deleter_QTextOption_Tab, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextOption::Tab
void __qt_destruct_QTextOption_Tab(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextOption::Tab")
    reinterpret_cast<QTextOption::Tab*>(ptr)->~Tab();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextOption::Tab::operator==(QTextOption::Tab)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_equals_1native_1cref_1QTextOption_1Tab_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextOption::Tab::operator==(QTextOption::Tab)const", __qt_this)
        const QTextOption::Tab& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QTextOption::Tab>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_setDelimiter_1native_1cref_1QChar__JC)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jchar delimiter0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QChar __qt_delimiter0 = qtjambi_cast<QChar>(__jni_env, delimiter0);
        __qt_this->delimiter = __qt_delimiter0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jchar JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_delimiter_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jchar __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QChar&  __qt_value = __qt_this->delimiter;
        __java_return_value = __qt_value.unicode();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_setPosition_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble position0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->position = static_cast<qreal>(position0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_position_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->position;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_setType_1native_1cref_1QTextOption_1TabType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTextOption::TabType __qt_type0 = qtjambi_cast<QTextOption::TabType>(__jni_env, type0);
        __qt_this->type = QTextOption::TabType(__qt_type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QTextOption::TabType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextOption_00024Tab_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTextOption::Tab *__qt_this = QtJambiAPI::objectFromNativeId<QTextOption::Tab>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTextOption_Tab(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTextOption::Tab>("QTextOption::Tab", "io/qt/gui/QTextOption$Tab");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextOption_Tab, {
        ConstructorInfo(&__qt_construct_QTextOption_Tab, nullptr)
       ,ConstructorInfo(&__qt_construct_QTextOption_Tab_cref_QTextOption_Tab, "Lio/qt/gui/QTextOption$Tab;")
       ,ConstructorInfo(&__qt_construct_QTextOption_Tab_qreal_QTextOption_TabType, "DLio/qt/gui/QTextOption$TabType;")
       ,ConstructorInfo(&__qt_construct_QTextOption_Tab_qreal_QTextOption_TabType_QChar, "DLio/qt/gui/QTextOption$TabType;C")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextOption_Tab);
    registerMetaType<QTextOption::Tab>("QTextOption::Tab");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
